@@ -1,4 +1,6 @@
 context("means")
+library(data.table)
+data.table::setDTthreads(1)
 
 test_that("point estimate - geometric",{
 
